@@ -1,7 +1,7 @@
-"""Messaging Framework for Python"""
+"""Messaging library for Python"""
 from __future__ import absolute_import
 
-VERSION = (3, 0, 2)
+VERSION = (3, 0, 3)
 __version__ = '.'.join(map(str, VERSION[0:3])) + ''.join(VERSION[3:])
 __author__ = 'Ask Solem'
 __contact__ = 'ask@celeryproject.org'
