@@ -8,6 +8,8 @@ Event loop implementation.
 """
 from __future__ import absolute_import
 
+import errno
+
 from collections import deque
 from contextlib import contextmanager
 from time import sleep
@@ -18,6 +20,7 @@ from amqp import promise
 from kombu.five import Empty, items, range
 from kombu.log import get_logger
 from kombu.utils import cached_property, fileno, reprcall
+from kombu.utils.compat import get_errno
 from kombu.utils.eventio import READ, WRITE, ERR, poll
 
 from .timer import Timer
@@ -147,8 +150,12 @@ class Hub(object):
                     entry()
                 except propagate:
                     raise
-                except MemoryError:
+                except (MemoryError, AssertionError):
                     raise
+                except OSError as exc:
+                    if get_errno(exc) == errno.ENOMEM:
+                        raise
+                    logger.error('Error in timer: %r', exc, exc_info=1)
                 except Exception as exc:
                     logger.error('Error in timer: %r', exc, exc_info=1)
         return min(max(delay or 0, min_delay), max_delay)
@@ -158,6 +165,7 @@ class Hub(object):
             self.poller.register(fd, flags)
         except ValueError:
             self._discard(fd)
+            raise
         else:
             dest = self.readers if flags & READ else self.writers
             if consolidate:
@@ -282,6 +290,7 @@ class Hub(object):
                 to_consolidate = []
                 try:
                     events = poll(poll_timeout)
+                    #print('[EVENTS]: %s' % (self.repr_events(events or []), ))
                 except ValueError:  # Issue 882
                     raise StopIteration()
 
@@ -310,6 +319,9 @@ class Hub(object):
                     if isinstance(cb, generator):
                         try:
                             next(cb)
+                        except OSError as exc:
+                            if get_errno(exc) == errno.EBADF:
+                                hub_remove(fileno)
                         except StopIteration:
                             hub_remove(fileno)
                         except Exception:
@@ -332,8 +344,8 @@ class Hub(object):
 
     def repr_events(self, events):
         return ', '.join(
-            '{0}->{1}'.format(
-                _rcb(self._callback_for(fd, fl, '{0!r}(GONE)'.format(fd))),
+            '{0}({1})->{2}'.format(
+                _rcb(self._callback_for(fd, fl, '(GONE)')), fd,
                 repr_flag(fl),
             )
             for fd, fl in events
@@ -350,9 +362,11 @@ class Hub(object):
     def _callback_for(self, fd, flag, *default):
         try:
             if flag & READ:
-                return self.readers[fileno(fd)]
+                return self.readers[fd]
             if flag & WRITE:
-                return self.writers[fileno(fd)]
+                if fd in self.consolidate:
+                    return self.consolidate_callback
+                return self.writers[fd]
         except KeyError:
             if default:
                 return default[0]
